@@ -24,11 +24,11 @@ class EKSStack(Stack):
         eks_instance_profile = permission.createIAMInstanceProfile(self, "eks-instance-profile", eks_role) 
         
         # EC2 EKS
-        # cluster = container.createEKS_EC2Cluster(self, eks_cluster_name, eks_role, vpc)
-        # nodegroup = container.addEKS_EC2ClusterNodeGroup(self, cluster) 
+        cluster = container.createEKS_EC2Cluster(self, eks_cluster_name, eks_role, vpc)
+        nodegroup = container.addEKS_EC2ClusterNodeGroup(self, cluster) 
 
         # FARGATE EKS
-        self.fargate = container.createEKS_FargateCluster(self, eks_cluster_name, eks_role, vpc)
+        # self.fargate = container.createEKS_FargateCluster(self, eks_cluster_name, eks_role, vpc)
 
 
 class EMR_EKSStack(Stack): 
