@@ -13,9 +13,9 @@ import base64
 
 def get_apns_certificate(cert_path, cert_pw):
     p12 = crypto.load_pkcs12(open(cert_path, 'rb').read(), cert_pw)
-    pem = crypto.dump_certificate(crypto.FILETYPE_PEM, p12.get_certificate()) 
+    pem = crypto.dump_certificate(crypto.FILETYPE_PEM, p12.get_certificate())  
     cert_str = pem.decode("utf-8").replace("\n","\\n")
-    return cert_str
+    return pem
 
 
 class NotificationStack(Stack): 
